"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
class AMQPPublisher {
    constructor(connection, logger) {
        this.connection = connection;
        this.logger = logger;
        this.channel = null;
    }
    async publish(exchange, routingKey, data) {
        const channel = await this.getOrCreateChannel();
        await channel.assertExchange(exchange, 'topic', { durable: false, autoDelete: false });
        await channel.publish(exchange, routingKey, Buffer.from(JSON.stringify(data)));
        this.logger('Message sent to Exchange "%s" with Routing Key "%s" (%j)', exchange, routingKey, data);
    }
    async getOrCreateChannel() {
        if (!this.channel) {
            this.channel = await this.connection.createChannel();
            this.channel.on('error', (err) => { this.logger('Publisher channel error: "%j"', err); });
        }
        return this.channel;
    }
}
exports.AMQPPublisher = AMQPPublisher;
