"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const common_1 = require("./common");
class AMQPSubscriber {
    constructor(connection, logger) {
        this.connection = connection;
        this.logger = logger;
        this.channel = null;
    }
    async subscribe(exchange, routingKey, action) {
        // Create and bind queue
        const channel = await this.getOrCreateChannel();
        await channel.assertExchange(exchange, 'topic', { durable: false, autoDelete: false });
        const queue = await channel.assertQueue('', { exclusive: true, durable: false, autoDelete: true });
        await channel.bindQueue(queue.queue, exchange, routingKey);
        // Listen for messages
        const opts = await channel.consume(queue.queue, (msg) => {
            let parsedMessage = common_1.Logger.convertMessage(msg);
            this.logger('Message arrived from Queue "%s" (%j)', queue.queue, parsedMessage);
            action(routingKey, parsedMessage);
        }, { noAck: true });
        this.logger('Subscribed to Queue "%s" (%s)', queue.queue, opts.consumerTag);
        // Dispose callback
        return async () => {
            this.logger('Disposing Subscriber to Queue "%s" (%s)', queue.queue, opts.consumerTag);
            const ch = await this.getOrCreateChannel();
            await ch.cancel(opts.consumerTag);
        };
    }
    async getOrCreateChannel() {
        if (!this.channel) {
            this.channel = await this.connection.createChannel();
            this.channel.on('error', (err) => { this.logger('Subscriber channel error: "%j"', err); });
        }
        return this.channel;
    }
}
exports.AMQPSubscriber = AMQPSubscriber;
